==> kjy-center-api-0.5.43-release-1.0.4-sources.jar: cn/com/duiba/kjy/api/dto/RocketMqTag.java <==
package cn.com.duiba.kjy.api.dto;


/**
 * Created by dugq on 2019-03-27.
 */
public abstract class RocketMqTag {

    /**
     * 微信支付，兑吧回调
     */
    public static final String TAG_PAY_NOTIFY = "charge";

    /**
     * 晚安问候推送消息
     */
    public static final String TAG_PUSH_EVENING_GREETING = "push_evening_greeting";

    /**
     * 客集集VIP公众号微信通知消息
     */
    public static final String TAG_KJJ_VIP_OA_WX_NOTIFY = "TAG_KJJ_VIP_OA_WX_NOTIFY";

    /**
     * 客集集批量推送消息
     */
    public static final String TAG_KJJ_BATCH_NOTIFY = "TAG_KJJ_BATCH_NOTIFY";

    /**
     * 代理人统计数据通知
     */
    public static final String TAG_KJJ_SELLER_SHARE_STATISTIC = "tag_seller_share_statistic";

    /**
     * 钉钉通知消息
     */
    public static final String TAG_KJJ_DING_TALK = "tag_kjj_ding_talk";

    private static final String TAG_NEW_VISIT_INFORMATION = "KJY_NEW_VISIT_INFORMATION";
    private static final String KJY_SIMPLE_INFORMATION = "KjySimpleInformation";
    private static final String KJY_CONTENT_PUSH_INFORMATION = "KjyContentPushInformation";
    private static final String KJY_CONTENT_GRAB_INFORMATION = "KjyContentGrabInformation";

    private static final String KJY_ACTIVITY_SUBMIT_MESSAGE = "KJY_ACTIVITY_SUBMIT_MESSAGE";

    private static final String KJY_VIP_UNSUBSCRIBE_MESSAGE = "KJY_VIP_UNSUBSCRIBE_MESSAGE";


    private static final String KJY_CONTENT_PUSH_AFTERNOON = "KJY_CONTENT_PUSH_AFTERNOON";

    private static final String KJY_SINGLE_FESTIVAL_PUSH = "KJY_SINGLE_FESTIVAL_PUSH";

    /**
     * 客集集销售员导入任务
     */
    public static final String KJY_SELLER_IMPORT_MESSAGE = "KjySellerImportMessage";

    /**
     * 私信相关的消息，包含客户进入聊天，客户留言，代理人留言
     */
    public static final String KJY_PRIVATE_CHAT_SEND_MESSAGE = "KJY_PRIVATE_CHAT_SEND_MESSAGE";

    /**
     * 赠品发货tag
     */
    public static final String KJY_SELLER_GIFT_SEND_MESSAGE = "KJY_GIFT_SEND_MESSAGE";

    public static final String KJY_NATIONAL_DAY_ADD_DATA = "KJY_NATIONAL_DAY_ADD_DATA";

    public static final String KJY_NATIONAL_DAY_CLEAN_USER = "KJY_NATIONAL_DAY_CLEAN_USER";

    public static final String KJY_NATIONAL_DAY_BALANCE_DATA = "KJY_NATIONAL_DAY_BALANCE_DATA";

    public static final String KJY_INCREASE_INVESTMENT_TAG = "KJY_INCREASE_INVESTMENT_TAG";
    /**
     * 会销扫码22小时/48小时后未付费，推送优惠过期提醒
     */
    public static final String KJY_SALES_PROMOTION_REMIND = "KJY_SALES_PROMOTION_REMIND";

    /**
     * 精准素材每半小时聚合推送
     */
    public static final String KJY_ACCURATE_AGGREGATION_PUSH_TAG = "KJY_ACCURATE_AGGREGATION_PUSH_TAG";

    public static String getKjyAccurateAggregationPushTag() {
        return KJY_ACCURATE_AGGREGATION_PUSH_TAG;
    }

    public static String getTagNewVisitInformation() {
        return TAG_NEW_VISIT_INFORMATION;
    }

    public static String getKjySimpleInformation() {
        return KJY_SIMPLE_INFORMATION;
    }

    public static String getKjyContentPushInformation() {
        return KJY_CONTENT_PUSH_INFORMATION;
    }

    public static String getKjySingleFestivalPush() {
        return KJY_SINGLE_FESTIVAL_PUSH;
    }

    public static String getKjyContentGrabInformation() {
        return KJY_CONTENT_GRAB_INFORMATION;
    }

    public static String getKjyActivitySubmitMessage() {
        return KJY_ACTIVITY_SUBMIT_MESSAGE;
    }

    public static String getKjyVipUnsubscribeMessage() {
        return KJY_VIP_UNSUBSCRIBE_MESSAGE;
    }

    public static String getKjyContentPushAfternoon() {
        return KJY_CONTENT_PUSH_AFTERNOON;
    }

    public static String getKjyNationalDayAddData() {
        return KJY_NATIONAL_DAY_ADD_DATA;
    }

    public static String getKjyNationalDayCleanUser() {
        return KJY_NATIONAL_DAY_CLEAN_USER;
    }

    public static String getKjyNationalDayBalanceData() {
        return KJY_NATIONAL_DAY_BALANCE_DATA;
    }

}

==> kjy-center-api-0.7.90-release-1.0.1-20200313.074828-1-sources.jar: cn/com/duiba/kjy/api/dto/RocketMqTag.java <==
package cn.com.duiba.kjy.api.dto;


/**
 * Created by dugq on 2019-03-27.
 */
public abstract class RocketMqTag {

    /**
     * 微信支付，兑吧回调
     */
    public static final String TAG_PAY_NOTIFY = "charge";

    /**
     * 微信退款，兑吧回调
     */
    public static final String TAG_PAY_REFUND = "refund";

    /**
     * 微信支付，客集集支付系统回调
     */
    public static final String TAG_PAY_NOTIFY_KJY = "charge_kjy";

    /**
     * 微信退款，客集集支付系统回调
     */
    public static final String TAG_PAY_REFUND_KJY = "refund_kjy";

    /**
     * 晚安问候推送消息
     */
    public static final String TAG_PUSH_EVENING_GREETING = "push_evening_greeting";

    /**
     * 客集集VIP公众号微信通知消息
     */
    public static final String TAG_KJJ_VIP_OA_WX_NOTIFY = "TAG_KJJ_VIP_OA_WX_NOTIFY";

    /**
     * 客集集批量推送消息
     */
    public static final String TAG_KJJ_BATCH_NOTIFY = "TAG_KJJ_BATCH_NOTIFY";

    /**
     * 代理人统计数据通知
     */
    public static final String TAG_KJJ_SELLER_SHARE_STATISTIC = "tag_seller_share_statistic";

    /**
     * 钉钉通知消息
     */
    public static final String TAG_KJJ_DING_TALK = "tag_kjj_ding_talk";

    private static final String TAG_NEW_VISIT_INFORMATION = "KJY_NEW_VISIT_INFORMATION";
    private static final String KJY_SIMPLE_INFORMATION = "KjySimpleInformation";
    private static final String KJY_CONTENT_PUSH_INFORMATION = "KjyContentPushInformation";
    private static final String KJY_CONTENT_GRAB_INFORMATION = "KjyContentGrabInformation";

    private static final String KJY_ACTIVITY_SUBMIT_MESSAGE = "KJY_ACTIVITY_SUBMIT_MESSAGE";

    private static final String KJY_VIP_UNSUBSCRIBE_MESSAGE = "KJY_VIP_UNSUBSCRIBE_MESSAGE";


    private static final String KJY_CONTENT_PUSH_AFTERNOON = "KJY_CONTENT_PUSH_AFTERNOON";

    private static final String KJY_SINGLE_FESTIVAL_PUSH = "KJY_SINGLE_FESTIVAL_PUSH";

    /**
     * 客集集销售员导入任务
     */
    public static final String KJY_SELLER_IMPORT_MESSAGE = "KjySellerImportMessage";

    /**
     * 私信相关的消息，包含客户进入聊天，客户留言，代理人留言
     */
    public static final String KJY_PRIVATE_CHAT_SEND_MESSAGE = "KJY_PRIVATE_CHAT_SEND_MESSAGE";

    /**
     * 赠品发货tag
     */
    public static final String KJY_SELLER_GIFT_SEND_MESSAGE = "KJY_GIFT_SEND_MESSAGE";

    public static final String KJY_NATIONAL_DAY_ADD_DATA = "KJY_NATIONAL_DAY_ADD_DATA";

    public static final String KJY_NATIONAL_DAY_CLEAN_USER = "KJY_NATIONAL_DAY_CLEAN_USER";

    public static final String KJY_NATIONAL_DAY_BALANCE_DATA = "KJY_NATIONAL_DAY_BALANCE_DATA";

    /**
     * 会销扫码22小时/48小时后未付费，推送优惠过期提醒
     */
    public static final String KJY_SALES_PROMOTION_REMIND = "KJY_SALES_PROMOTION_REMIND";

    /**
     * 精准素材每半小时聚合推送
     */
    public static final String KJY_ACCURATE_AGGREGATION_PUSH_TAG = "KJY_ACCURATE_AGGREGATION_PUSH_TAG";

    /**
     * 客服消息关闭预警客服消息推送
     */
    public static final String INTERACT_WILL_EXPIRE_REMIND_TAG = "INTERACT_WILL_EXPIRE_REMIND_TAG";

    /**
     * 已沉睡用户唤醒客服消息推送
     */
    public static final String INTERACT_EXPIRE_REMIND_TAG = "INTERACT_EXPIRE_REMIND_TAG";

    /**
     * 元旦活动点赞通知推送
     */
    public static final String NEW_YEAR_LIKE_REMIND_TAG = "NEW_YEAR_LIKE_REMIND_TAG";

    /**
     * 元旦活动转发通知推送
     */
    public static final String NEW_YEAR_FORWARD_REMIND_TAG = "NEW_YEAR_FORWARD_REMIND_TAG";

    /**
     * 晚安问候消息推送
     */
    public static final String EVENING_GREETING_PUSH_TAG = "EVENING_GREETING_PUSH_TAG";


    /**
     * 今日运势消息推送
     */
    public static final String TODAY_LUCK_PUSH_TAG = "TODAY_LUCK_PUSH_TAG";

    /**
     * 优惠码到期提醒
     */
    public static final String PROMOTION_CODE_WILL_EXPIRE_REMIND = "PROMOTION_CODE_WILL_EXPIRE_REMIND";

    /**
     * 访问线索延迟分析
     */
    public static final String VISIT_CLUE_DELAY_ANALYSE_PUSH = "VISIT_CLUE_DELAY_ANALYSE_PUSH";


    public static String getDailySignTag() {
        return DAILY_SIGN_TAG;
    }

    /**
     * 今日日签
     */
    public static final String DAILY_SIGN_TAG = "DAILY_SIGN_TAG";


    public static String getKjyAccurateAggregationPushTag() {
        return KJY_ACCURATE_AGGREGATION_PUSH_TAG;
    }

    public static String getTagNewVisitInformation() {
        return TAG_NEW_VISIT_INFORMATION;
    }

    public static String getKjySimpleInformation() {
        return KJY_SIMPLE_INFORMATION;
    }

    public static String getKjyContentPushInformation() {
        return KJY_CONTENT_PUSH_INFORMATION;
    }

    public static String getKjySingleFestivalPush() {
        return KJY_SINGLE_FESTIVAL_PUSH;
    }

    public static String getKjyContentGrabInformation() {
        return KJY_CONTENT_GRAB_INFORMATION;
    }

    public static String getKjyActivitySubmitMessage() {
        return KJY_ACTIVITY_SUBMIT_MESSAGE;
    }

    public static String getKjyVipUnsubscribeMessage() {
        return KJY_VIP_UNSUBSCRIBE_MESSAGE;
    }

    public static String getKjyContentPushAfternoon() {
        return KJY_CONTENT_PUSH_AFTERNOON;
    }

    public static String getKjyNationalDayAddData() {
        return KJY_NATIONAL_DAY_ADD_DATA;
    }

    public static String getKjyNationalDayCleanUser() {
        return KJY_NATIONAL_DAY_CLEAN_USER;
    }

    public static String getKjyNationalDayBalanceData() {
        return KJY_NATIONAL_DAY_BALANCE_DATA;
    }

    public static String getInteractWillExpireRemindTag() {
        return INTERACT_WILL_EXPIRE_REMIND_TAG;
    }

    public static String getInteractExpireRemindTag() {
        return INTERACT_EXPIRE_REMIND_TAG;
    }

    public static String getNewYearLikeRemindTag() {
        return NEW_YEAR_LIKE_REMIND_TAG;
    }

    public static String getNewYearForwardRemindTag() {
        return NEW_YEAR_FORWARD_REMIND_TAG;
    }

    public static String getVisitClueDelayAnalysePush() {
        return VISIT_CLUE_DELAY_ANALYSE_PUSH;
    }
}
